@@ -3,9 +3,9 @@
  *
  * Common functions for SAKURA and TOMOYO.
  *
- * Copyright (C) 2005-2009  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.6.8+   2009/07/03
+ * Version: 1.6.9+   2011/05/05
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -1134,7 +1134,11 @@ static int ccs_write_profile(struct ccs_io_buffer *head)
 	*cp = '\0';
 	ccs_update_counter(CCS_UPDATES_COUNTER_PROFILE);
 	if (!strcmp(data, "COMMENT")) {
-		ccs_profile->comment = ccs_save_name(cp + 1);
+		const struct ccs_path_info *new_comment
+			= ccs_save_name(cp + 1);
+		if (!new_comment)
+			return -ENOMEM;
+		ccs_profile->comment = new_comment;
 		ccs_profile_entry_used[0] = true;
 		return 0;
 	}
@@ -1503,11 +1507,11 @@ static bool ccs_is_select_one(struct ccs_io_buffer *head, const char *data)
 	if (sscanf(data, "pid=%u", &pid) == 1) {
 		struct task_struct *p;
 		/***** CRITICAL SECTION START *****/
-		read_lock(&tasklist_lock);
+		ccs_tasklist_lock();
 		p = find_task_by_pid(pid);
 		if (p)
 			domain = ccs_task_domain(p);
-		read_unlock(&tasklist_lock);
+		ccs_tasklist_unlock();
 		/***** CRITICAL SECTION END *****/
 	} else if (!strncmp(data, "domain=", 7)) {
 		if (ccs_is_domain_def(data + 7))
@@ -2233,13 +2237,13 @@ static int ccs_read_pid(struct ccs_io_buffer *head)
 		task_info = true;
 	pid = (unsigned int) simple_strtoul(buf, NULL, 10);
 	/***** CRITICAL SECTION START *****/
-	read_lock(&tasklist_lock);
+	ccs_tasklist_lock();
 	p = find_task_by_pid(pid);
 	if (p) {
 		domain = ccs_task_domain(p);
 		ccs_flags = p->ccs_flags;
 	}
-	read_unlock(&tasklist_lock);
+	ccs_tasklist_unlock();
 	/***** CRITICAL SECTION END *****/
 	if (!domain)
 		goto done;
@@ -2482,7 +2486,7 @@ static bool ccs_policy_loader_exists(void)
 	 * exist. If the initrd includes /sbin/init but real-root-dev has not
 	 * mounted on / yet, activating MAC will block the system since
 	 * policies are not loaded yet.
-	 * Thus, let do_execve() call this function everytime.
+	 * Thus, let do_execve() call this function every time.
 	 */
 	struct nameidata nd;
 	if (!ccs_loader)
@@ -2604,10 +2608,10 @@ void ccs_load_policy(const char *filename)
 	}
 #endif
 #ifdef CONFIG_SAKURA
-	printk(KERN_INFO "SAKURA: 1.6.8   2009/05/28\n");
+	printk(KERN_INFO "SAKURA: 1.6.9+   2011/05/05\n");
 #endif
 #ifdef CONFIG_TOMOYO
-	printk(KERN_INFO "TOMOYO: 1.6.8+   2009/07/03\n");
+	printk(KERN_INFO "TOMOYO: 1.6.9+   2011/05/05\n");
 #endif
 	printk(KERN_INFO "Mandatory Access Control activated.\n");
 	ccs_policy_loaded = true;
@@ -3048,7 +3052,7 @@ static int ccs_read_updates_counter(struct ccs_io_buffer *head)
 static int ccs_read_version(struct ccs_io_buffer *head)
 {
 	if (!head->read_eof) {
-		ccs_io_printf(head, "1.6.8");
+		ccs_io_printf(head, "1.6.9");
 		head->read_eof = true;
 	}
 	return 0;
